.. _integrations:

Integrations
------------

.. _aiobotocore:

aiobotocore
^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.aiobotocore


.. _aiopg:

aiopg
^^^^^
.. automodule:: ddtrace.contrib.internal.aiopg


.. _algoliasearch:

algoliasearch
^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.algoliasearch

.. _aredis:

aredis
^^^^^^
.. automodule:: ddtrace.contrib.internal.aredis

.. _asgi:

asgi
^^^^
.. automodule:: ddtrace.contrib.asgi

.. _aiohttp:

aiohttp
^^^^^^^
.. automodule:: ddtrace.contrib.aiohttp

.. _aiohttp_jinja2:

aiohttp-jinja2
^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.aiohttp_jinja2

.. _aiomysql:

aiomysql
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.aiomysql


.. _anthropic:

anthropic
^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.anthropic


.. _asyncio:

asyncio
^^^^^^^
.. automodule:: ddtrace.contrib.internal.asyncio


.. _asyncpg:

asyncpg
^^^^^^^
.. automodule:: ddtrace.contrib.internal.asyncpg


.. _avro:

avro
^^^^
.. automodule:: ddtrace.contrib.internal.avro


.. _azure_functions:

Azure Functions
^^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.azure_functions


.. _botocore:

botocore
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.botocore


.. _boto2:

boto2
^^^^^
.. automodule:: ddtrace.contrib.internal.boto


.. _bottle:

Bottle
^^^^^^
.. automodule:: ddtrace.contrib.bottle


.. _cassandra:

Cassandra
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.cassandra


.. _celery:

Celery
^^^^^^
.. automodule:: ddtrace.contrib.celery


.. _cherrypy:

CherryPy
^^^^^^^^
.. automodule:: ddtrace.contrib.cherrypy


.. _consul:

Consul
^^^^^^
.. automodule:: ddtrace.contrib.internal.consul


.. _coverage:

Coverage
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.coverage


.. _crewai:

CrewAI
^^^^^^
.. automodule:: ddtrace.contrib.internal.crewai


.. _datadog_lambda:

datadog_lambda
==============
.. automodule:: ddtrace.contrib.internal.aws_lambda


.. _djangorestframework:
.. _django:

Django
^^^^^^
.. automodule:: ddtrace.contrib.internal.django


.. _dogpile.cache:

dogpile.cache
^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.dogpile_cache


.. _dramatiq:

Dramatiq
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.dramatiq


.. _elasticsearch:

Elasticsearch
^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.elasticsearch


.. _falcon:

Falcon
^^^^^^
.. automodule:: ddtrace.contrib.falcon


.. _fastapi:

Fastapi
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.fastapi


.. _flask:

Flask
^^^^^
.. automodule:: ddtrace.contrib.internal.flask


.. _flask_cache:

Flask Cache
^^^^^^^^^^^
.. automodule:: ddtrace.contrib.flask_cache


.. _freezegun:

FreezeGun
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.freezegun


.. _futures:

futures
^^^^^^^
.. automodule:: ddtrace.contrib.internal.futures


.. _gevent:

gevent
^^^^^^
.. automodule:: ddtrace.contrib.internal.gevent


.. _google_adk:

google-adk
^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.google_adk


.. _google_genai:

google-genai
^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.google_genai

.. _google_generativeai:

google-generativeai
^^^^^^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.google_generativeai


.. _graphql:

graphql
^^^^^^^
.. automodule:: ddtrace.contrib.internal.graphql


.. _grpc:

Grpc
^^^^
.. automodule:: ddtrace.contrib.internal.grpc


.. _gunicorn:

gunicorn
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.gunicorn


.. _httplib:

httplib
^^^^^^^
.. automodule:: ddtrace.contrib.internal.httplib

.. _httpx:

httpx
^^^^^
.. automodule:: ddtrace.contrib.internal.httpx


.. _jinja2:

Jinja2
^^^^^^
.. automodule:: ddtrace.contrib.internal.jinja2

.. _kafka:

Kafka
^^^^^

.. automodule:: ddtrace.contrib.internal.kafka

.. _kombu:

kombu
^^^^^
.. automodule:: ddtrace.contrib.internal.kombu

.. _langchain:

LangChain
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.langchain

.. _langgraph:

LangGraph
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.langgraph

.. _litellm:

LiteLLM
^^^^^^^
.. automodule:: ddtrace.contrib.internal.litellm

.. _logbook:

Logbook
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.logbook

.. _logging:

Logging
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.logging

.. _loguru:

Loguru
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.loguru


.. _mako:

Mako
^^^^
.. automodule:: ddtrace.contrib.internal.mako


.. _mcp:

MCP
^^^
.. automodule:: ddtrace.contrib.internal.mcp


.. _mariadb:

MariaDB
^^^^^^^
.. automodule:: ddtrace.contrib.internal.mariadb


.. _molten:

Molten
^^^^^^
.. automodule:: ddtrace.contrib.internal.molten


.. _mongoengine:

Mongoengine
^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.mongoengine


.. _mysql-connector:

mysql-connector
^^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.mysql


.. _mysqlclient:
.. _mysqldb:

mysqlclient
^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.mysqldb


.. _openai:

OpenAI
^^^^^^
.. automodule:: ddtrace.contrib.internal.openai


.. _openai-agents:

OpenAI Agents
^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.openai_agents


.. _pylibmc:

pylibmc
^^^^^^^
.. automodule:: ddtrace.contrib.pylibmc


.. _pynamodb:

PynamoDB
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.pynamodb


.. _pyodbc:

PyODBC
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.pyodbc


.. _pymemcache:

pymemcache
^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.pymemcache


.. _pymongo:

Pymongo
^^^^^^^
.. automodule:: ddtrace.contrib.internal.pymongo


.. _pymysql:

pymysql
^^^^^^^
.. automodule:: ddtrace.contrib.internal.pymysql


.. _pyramid:

Pyramid
^^^^^^^
.. automodule:: ddtrace.contrib.pyramid


.. _pytest:

pytest
^^^^^^
.. automodule:: ddtrace.contrib.internal.pytest


.. _pytest_bdd:

pytest-bdd
^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.pytest_bdd

.. _pytest_benchmark:

pytest-benchmark
^^^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.pytest_benchmark

.. _protobuf:

protobuf
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.protobuf

.. _psycopg:

psycopg
^^^^^^^
.. automodule:: ddtrace.contrib.internal.psycopg


.. _ray:

Ray
^^^
.. automodule:: ddtrace.contrib.internal.ray


.. _redis:

redis
^^^^^
.. automodule:: ddtrace.contrib.internal.redis


.. _rediscluster:

redis-py-cluster
^^^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.rediscluster


.. _requests:

Requests
^^^^^^^^
.. automodule:: ddtrace.contrib.requests


.. _rq:

RQ
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.rq


.. _sanic:

Sanic
^^^^^
.. automodule:: ddtrace.contrib.internal.sanic


.. _selenium:

Selenium
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.selenium


.. _snowflake:

Snowflake
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.snowflake


.. _starlette:

Starlette
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.starlette


.. _structlog:

Structlog
^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.structlog


.. _sqlalchemy:

SQLAlchemy
^^^^^^^^^^
.. automodule:: ddtrace.contrib.sqlalchemy


.. _sqlite:

SQLite
^^^^^^
.. automodule:: ddtrace.contrib.internal.sqlite3


.. _subprocess:

Subprocess
^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.subprocess


.. _tornado:

Tornado
^^^^^^^
.. automodule:: ddtrace.contrib.tornado


.. _unittest:

unittest
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.unittest


.. _urllib:

urllib
^^^^^^
.. automodule:: ddtrace.contrib.internal.urllib


.. _urllib3:

urllib3
^^^^^^^
.. automodule:: ddtrace.contrib.internal.urllib3


.. _valkey:

valkey
^^^^^^
.. automodule:: ddtrace.contrib.valkey


.. _vertexai:

vertexai
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.vertexai


.. _vertica:

Vertica
^^^^^^^
.. automodule:: ddtrace.contrib.internal.vertica

.. _webbrowser:

Webbrowser
^^^^^^^^^^
.. automodule:: ddtrace.contrib.internal.webbrowser

.. _wsgi:

WSGI
^^^^
.. automodule:: ddtrace.contrib.wsgi

.. _yaaredis:

yaaredis
^^^^^^^^
.. automodule:: ddtrace.contrib.internal.yaaredis
